#include <QtGui/QApplication>
#include "wolan.h"

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    wolan w;
#if defined(Q_WS_S60)
    w.showMaximized();
#else
    w.show();
#endif

    return a.exec();
}
